"""Tests for the data-structures package.

Modules
-------

    test_elements:
        Classes
        -------
            TestNumber: Tests for the Number class.

    test_stacks:
        Classes
        -------
            TestStack: Tests for the Stack class.

    test_queues:
        Classes
        -------
            TestQueue: Tests for the Queue class.
"""
